@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0403';
+our $VERSION = '0.0404';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -274,7 +274,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0403
+version 0.0404
 
 =head1 SYNOPSIS
 
@@ -303,7 +303,7 @@ notes until they sound suitable.
 
 The "formula" implemented by this module is basically: "Play any notes
 of the chord, modal chord scale, or chord-root scale (and drop any
-accidental notes replaced by extended jazz chords)."
+notes replaced by extended jazz chords)."
 
 The chords recognized by this module, are those known to
 L<Music::Chord::Note>.  Please see the source of that module for the
@@ -366,7 +366,9 @@ Default: C<2>
 
 The musical scale to use, based on a given chord (i.e. C<$_[0]> here).
 
-Default: C<sub { $_[0] =~ /^[A-G][#b]?m/ ? 'minor' : 'major' }>
+Default if not B<modal>:
+
+  sub { $_[0] =~ /^[A-G][#b]?m/ ? 'minor' : 'major' }
 
 Alternatives:
 
@@ -378,8 +380,8 @@ Alternatives:
 
 The first walks the chromatic scale no matter what the chord.  The
 second walks either the major or minor pentatonic scale, plus the
-notes of the chord.  The last walks only the notes of the chord (no
-scale).
+notes of the chord (unless the B<chord_notes> attribute is C<0>).
+The last walks only the notes of the chord (no scale).
 
 =head2 tonic
 
